@@ -32,31 +32,14 @@ class TelethonPDAImplementation(engi.ConversationListImplementation):
     .. todo:: Document this.
     """
 
-    def _partialcommand_pattern(self, partial) -> str:
-        if partial.syntax:
-            return rf"^/{{name}}(?:@{self.bot_username})?\s+{{syntax}}$"
-        else:
-            return rf"^/{{name}}(?:@{self.bot_username})?$"
-
     @property
     def namespace(self):
         return "telethon"
 
     def __init__(self, name: str, tg_api_id: int, tg_api_hash: str, bot_username: str, bot_token: str,
-                 mode: TelethonPDAMode = TelethonPDAMode.CHAT_USER, extensions=None):
+                 mode: TelethonPDAMode = TelethonPDAMode.CHAT_USER):
 
-        super().__init__(name=name, extensions=extensions)
-
-        self.dispensers: dict[t.Any, engi.Dispenser] = {}
-        """
-        The :class:`royalnet.engineer.dispenser.Dispenser`\\ s of this PDA.
-        """
-
-        self.conversations: t.List[engi.Conversation] = []
-        """
-        A :class:`list` of conversations to run before a new _event is :meth:`.put` in a 
-        :class:`~royalnet.engineer.dispenser.Dispenser`.
-        """
+        super().__init__(name=name)
 
         self.mode: TelethonPDAMode = mode
         """
@@ -129,7 +112,7 @@ class TelethonPDAImplementation(engi.ConversationListImplementation):
         .. todo:: Document this.
         """
 
-        await self.put_projectile(
+        await self.put(
             key=self._determine_key(event),
             projectile=TelegramMessageReceived(event=event),
         )
@@ -139,7 +122,7 @@ class TelethonPDAImplementation(engi.ConversationListImplementation):
         .. todo:: Document this.
         """
 
-        await self.put_projectile(
+        await self.put(
             key=self._determine_key(event),
             projectile=TelegramMessageEdited(event=event),
         )
@@ -149,7 +132,7 @@ class TelethonPDAImplementation(engi.ConversationListImplementation):
         .. todo:: Document this.
         """
 
-        await self.put_projectile(
+        await self.put(
             key=self._determine_key(event),
             projectile=TelegramMessageDeleted(event=event),
         )
@@ -168,14 +151,6 @@ class TelethonPDAImplementation(engi.ConversationListImplementation):
         finally:
             await client.disconnect()
 
-    async def _handle_conversation_exc(
-            self,
-            dispenser: engi.Dispenser,
-            conv: engi.ConversationProtocol,
-            exception: Exception,
-    ) -> None:
-        self.log.error(f"Unhandled exception in {dispenser} running {conv}: {exception}")
-
 
 __all__ = (
     "TelethonPDAImplementation",
